from distutils.core import setup
setup(
    name = 'nestinho',
    version = '1.3.0',
    py_modules = ['nestinho'],
    author = 'naerith',
    author_email = 'busraasan2@gmail.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
)
